Simple tests
------------

Ensure your device works with these simple tests.

Mono
====

.. literalinclude:: ../examples/charlcd_mono_simpletest.py
    :caption: examples/charlcd_mono_simpletest.py
    :linenos:

RGB
===

.. literalinclude:: ../examples/charlcd_rgb_simpletest.py
    :caption: examples/charlcd_rgb_simpletest.py
    :linenos:

I2C Mono
========

.. literalinclude:: ../examples/charlcd_i2c_mono_simpletest.py
    :caption: examples/charlcd_i2c_mono_simpletest.py
    :linenos:

I2C RGB
=======

.. literalinclude:: ../examples/charlcd_i2c_rgb_simpletest.py
    :caption: examples/charlcd_i2c_rgb_simpletest.py
    :linenos:

SPI Mono
========

.. literalinclude:: ../examples/charlcd_spi_mono_simpletest.py
    :caption: examples/charlcd_spi_mono_simpletest.py
    :linenos:

Keypad
======

.. literalinclude:: ../examples/charlcd_keypad_simpletest.py
    :caption: examples/charlcd_keypad_simpletest.py
    :linenos:

Raspberry Pi Mono
=================

.. literalinclude:: ../examples/charlcd_rpi_mono_simpletest.py
    :caption: examples/charlcd_rpi_mono_simpletest.py
    :linenos:

Raspberry Pi RGB
================

.. literalinclude:: ../examples/charlcd_rpi_rgb_simpletest.py
    :caption: examples/charlcd_rpi_rgb_simpletest.py
    :linenos:

Other tests
-----------

Custom Character
================

.. literalinclude:: ../examples/charlcd_customcharacter.py
    :caption: examples/charlcd_customcharacter.py
    :linenos:

Nyan Cat
========

.. literalinclude:: ../examples/charlcd_custom_character_nyan_cat.py
    :caption: examples/charlcd_custom_character_nyan_cat.py
    :linenos:
